@@ -8,7 +8,7 @@ import pydicom
 from PySide6.QtCore import Qt, QThreadPool, QFileSystemWatcher
 from PySide6.QtGui import QFont
 from PySide6.QtSvgWidgets import QSvgWidget
-from PySide6.QtWidgets import (QTabWidget, QWidget, QGridLayout, QLabel,
+from PySide6.QtWidgets import (QTabWidget, QWidget, QGridLayout, QLabel, QHeaderView,
                                QPushButton, QSizePolicy, QHBoxLayout,
                                QGroupBox, QVBoxLayout, QMessageBox, QListWidget,
                                QFileDialog, QTreeWidget, QErrorMessage, QFileSystemModel,
@@ -20,7 +20,6 @@ from swane.nipype_pipeline.MainWorkflow import MainWorkflow
 from swane.ui.workers.WorkflowGeneratorWorker import WorkflowGeneratorWorker
 from swane.ui.workers.WorkflowMonitorWorker import WorkflowMonitorWorker
 from swane.ui.workers.WorkflowProcess import WorkflowProcess
-from swane.nipype_pipeline.engine.MonitoredMultiProcPlugin import MonitoredMultiProcPlugin
 from swane.ui.CustomTreeWidgetItem import CustomTreeWidgetItem
 from swane.ui.PersistentProgressDialog import PersistentProgressDialog
 from swane.ui.PreferencesWindow import PreferencesWindow
@@ -35,7 +34,6 @@ class PtTab(QTabWidget):
     DATATAB = 0
     EXECTAB = 1
     RESULTTAB = 2
-    NODE_HOLDER = 'customTreeWidgetItem'
     GRAPH_DIR_NAME = "graph"
     GRAPH_FILE_PREFIX = "graph_"
     GRAPH_FILE_EXT = "svg"
@@ -76,17 +74,20 @@ class PtTab(QTabWidget):
         self.setTabEnabled(PtTab.EXECTAB, False)
         self.setTabEnabled(PtTab.RESULTTAB, False)
 
+    def set_main_window(self, main_window):
+        self.main_window = main_window
+
     def update_node_list(self, msg):
 
         if msg == WorkflowMonitorWorker.STOP:
             errors = False
             for key in self.node_list.keys():
-                self.node_list[key][PtTab.NODE_HOLDER].setExpanded(False)
-                if not self.node_list[key][PtTab.NODE_HOLDER].completed:
+                self.node_list[key].node_holder.setExpanded(False)
+                if not self.node_list[key].node_holder.completed:
                     errors = True
-                    for subkey in self.node_list[key].keys():
-                        if subkey != PtTab.NODE_HOLDER and self.node_list[key][subkey].art == self.main_window.ERROR_ICON_FILE:
-                            self.node_list[key][PtTab.NODE_HOLDER].setArt(self.main_window.ERROR_ICON_FILE)
+                    for subkey in self.node_list[key].node_list.keys():
+                        if self.node_list[key].node_list[subkey].node_holder.art == self.main_window.ERROR_ICON_FILE:
+                            self.node_list[key].node_holder.setArt(self.main_window.ERROR_ICON_FILE)
                             break
 
             self.setTabEnabled(PtTab.DATATAB, True)
@@ -99,10 +100,10 @@ class PtTab(QTabWidget):
             self.enable_tab_if_result_dir()
             return
 
-        if msg == MonitoredMultiProcPlugin.WORKFLOW_INSUFFICIENT_RESOURCES:
-            msg_box = QMessageBox()
-            msg_box.setText(strings.pttab_wf_insufficient_resources)
-            msg_box.exec()
+        # if msg == WorkflowProcess.WORKFLOW_INSUFFICIENT_RESOURCES:
+        #     msg_box = QMessageBox()
+        #     msg_box.setText(strings.pttab_wf_insufficient_resources)
+        #     msg_box.exec()
 
         split = msg.split(PtTab.NODE_MSG_DIVIDER)
 
@@ -113,33 +114,33 @@ class PtTab(QTabWidget):
         if len(split) < 3:
             return
 
-        if split[2] == MonitoredMultiProcPlugin.NODE_STARTED:
+        if split[2] == WorkflowProcess.NODE_STARTED:
             icon = self.main_window.LOADING_MOVIE_FILE
-        elif split[2] == MonitoredMultiProcPlugin.NODE_COMPLETED:
+        elif split[2] == WorkflowProcess.NODE_COMPLETED:
             icon = self.main_window.OK_ICON_FILE
         else:
             icon = self.main_window.ERROR_ICON_FILE
 
-        self.node_list[split[0]][split[1]].setArt(icon)
+        self.node_list[split[0]].node_list[split[1]].node_holder.setArt(icon)
 
-        self.node_list[split[0]][PtTab.NODE_HOLDER].setExpanded(True)
+        self.node_list[split[0]].node_holder.setExpanded(True)
 
         if icon == self.main_window.OK_ICON_FILE:
             completed = True
-            for key in self.node_list[split[0]].keys():
-                if key != PtTab.NODE_HOLDER and self.node_list[split[0]][key].art != self.main_window.OK_ICON_FILE:
+            for key in self.node_list[split[0]].node_list.keys():
+                if self.node_list[split[0]].node_list[key].node_holder.art != self.main_window.OK_ICON_FILE:
                     completed = False
                     break
             if completed:
-                self.node_list[split[0]][PtTab.NODE_HOLDER].setArt(self.main_window.OK_ICON_FILE)
-                self.node_list[split[0]][PtTab.NODE_HOLDER].setExpanded(False)
-                self.node_list[split[0]][PtTab.NODE_HOLDER].completed = True
+                self.node_list[split[0]].node_holder.setArt(self.main_window.OK_ICON_FILE)
+                self.node_list[split[0]].node_holder.setExpanded(False)
+                self.node_list[split[0]].node_holder.completed = True
 
     def remove_running_icon(self):
         for key1 in self.node_list.keys():
-            for key2 in self.node_list[key1].keys():
-                if self.node_list[key1][key2].art == self.main_window.LOADING_MOVIE_FILE:
-                    self.node_list[key1][key2].setArt(self.main_window.VOID_SVG_FILE)
+            for key2 in self.node_list[key1].node_list.keys():
+                if self.node_list[key1].node_list[key2].node_holder.art == self.main_window.LOADING_MOVIE_FILE:
+                    self.node_list[key1].node_list[key2].node_holder.setArt(self.main_window.VOID_SVG_FILE)
 
     def start_gen_wf_thread(self):
         # questa funzione serve a generare il wf in un thread a pare durante il caricamento del pz
@@ -161,8 +162,7 @@ class PtTab(QTabWidget):
             self.wf_type_combo.setEnabled(True)
             self.pt_config_button.setEnabled(True)
 
-            if self.data_input_list.is_ref_loaded():
-                self.setTabEnabled(PtTab.EXECTAB, True)
+            self.enable_exec_tab()
 
         except AttributeError:
             pass
@@ -325,7 +325,13 @@ class PtTab(QTabWidget):
 
         self.node_list_treeWidget = QTreeWidget()
         self.node_list_treeWidget.setHeaderHidden(True)
-        self.node_list_treeWidget.setFixedWidth(320)
+        node_list_width = 320
+        self.node_list_treeWidget.setFixedWidth(node_list_width)
+        self.node_list_treeWidget.header().setMinimumSectionSize(node_list_width)
+        self.node_list_treeWidget.header().setSectionResizeMode(QHeaderView.ResizeToContents)
+        self.node_list_treeWidget.header().setStretchLastSection(False)
+        self.node_list_treeWidget.setHorizontalScrollBarPolicy(Qt.ScrollBarAsNeeded)
+        self.node_list_treeWidget.horizontalScrollBar().setEnabled(True)
 
         layout.addWidget(self.node_list_treeWidget, 2, 0)
         self.node_list_treeWidget.itemClicked.connect(self.tree_item_clicked)
@@ -382,26 +388,24 @@ class PtTab(QTabWidget):
         os.mkdir(graph_dir)
 
         for node in self.node_list.keys():
-            self.node_list[node][PtTab.NODE_HOLDER] = CustomTreeWidgetItem(self.node_list_treeWidget,
-                                                                          self.node_list_treeWidget, node)
-            if len(self.node_list[node].keys()) > 1:
+            self.node_list[node].node_holder = CustomTreeWidgetItem(self.node_list_treeWidget, self.node_list_treeWidget, self.node_list[node].long_name)
+            if len(self.node_list[node].node_list.keys()) > 0:
                 if self.main_window.graphviz:
+                    graph_name = self.node_list[node].long_name.lower().replace(" ", "_")
                     thread = Thread(target=self.workflow.get_node(node).write_graph,
                                     kwargs={'graph2use': self.GRAPH_TYPE, 'format': PtTab.GRAPH_FILE_EXT,
                                             'dotfilename': os.path.join(graph_dir,
-                                                                        PtTab.GRAPH_FILE_PREFIX + node + '.dot')})
+                                                                        PtTab.GRAPH_FILE_PREFIX + graph_name + '.dot')})
                     thread.start()
-                for sub_node in self.node_list[node].keys():
-                    if sub_node != PtTab.NODE_HOLDER:
-                        self.node_list[node][sub_node] = CustomTreeWidgetItem(self.node_list[node][PtTab.NODE_HOLDER],
-                                                                              self.node_list_treeWidget, sub_node)
+                for sub_node in self.node_list[node].node_list.keys():
+                    self.node_list[node].node_list[sub_node].node_holder = CustomTreeWidgetItem(self.node_list[node].node_holder, self.node_list_treeWidget, self.node_list[node].node_list[sub_node].long_name)
         self.exec_button.setEnabled(True)
         self.exec_button.setText(strings.EXECBUTTONTEXT)
         self.node_button.setEnabled(False)
 
     def tree_item_clicked(self, item, col):
         if self.main_window.graphviz and item.parent() is None:
-            file = os.path.join(self.pt_folder, PtTab.GRAPH_DIR_NAME, PtTab.GRAPH_FILE_PREFIX + item.getText() + '.'
+            file = os.path.join(self.pt_folder, PtTab.GRAPH_DIR_NAME, PtTab.GRAPH_FILE_PREFIX + item.getText().lower().replace(" ", "_") + '.'
                                 + PtTab.GRAPH_FILE_EXT)
             self.exec_graph.load(file)
             self.exec_graph.renderer().setAspectRatioMode(Qt.AspectRatioMode.KeepAspectRatio)
@@ -610,7 +614,7 @@ class PtTab(QTabWidget):
 
         self.data_input_list[input_name].loaded = True
 
-        self.setTabEnabled(PtTab.EXECTAB, self.data_input_list.is_ref_loaded())
+        self.enable_exec_tab()
 
     def check_input_folder(self, input_name, progress=None):
         dicom_src_work = self.check_input_folder_step1(input_name)
@@ -635,7 +639,7 @@ class PtTab(QTabWidget):
 
         self.set_error(input_name, strings.pttab_no_dicom_error + src_path)
         self.data_input_list[input_name].loaded = False
-        self.setTabEnabled(PtTab.EXECTAB, self.data_input_list.is_ref_loaded())
+        self.enable_exec_tab()
 
         progress.accept()
         self.reset_workflow()
@@ -720,3 +724,7 @@ class PtTab(QTabWidget):
 
     def close_routine(self):
         self.pt_config.save()
+
+    def enable_exec_tab(self):
+        enable = self.data_input_list.is_ref_loaded() and self.main_window.fsl and self.main_window.dcm2niix
+        self.setTabEnabled(PtTab.EXECTAB, enable)
